MastNodeExt

Trait MastNodeExt 

pub trait MastNodeExt {
Show 13 methods // Required methods fn digest(&self) -> Word; fn before_enter(&self) -> &[DecoratorId]; fn after_exit(&self) -> &[DecoratorId]; fn append_before_enter(&mut self, decorator_ids: &[DecoratorId]); fn append_after_exit(&mut self, decorator_ids: &[DecoratorId]); fn remove_decorators(&mut self); fn to_display<'a>( &'a self, mast_forest: &'a MastForest, ) -> Box<dyn Display + 'a>; fn to_pretty_print<'a>( &'a self, mast_forest: &'a MastForest, ) -> Box<dyn PrettyPrint + 'a>; fn remap_children( &self, remapping: &BTreeMap<MastNodeId, MastNodeId>, ) -> Self; fn has_children(&self) -> bool; fn append_children_to(&self, target: &mut Vec<MastNodeId>); fn for_each_child<F>(&self, f: F) where F: FnMut(MastNodeId); fn domain(&self) -> BaseElement;
}

Required Methods

fn digest(&self) -> Word

Returns a commitment/hash of the node.

fn before_enter(&self) -> &[DecoratorId]

Returns the decorators to be executed before this node is executed.

fn after_exit(&self) -> &[DecoratorId]

Returns the decorators to be executed after this node is executed.

fn append_before_enter(&mut self, decorator_ids: &[DecoratorId])

Sets the list of decorators to be executed before this node.

fn append_after_exit(&mut self, decorator_ids: &[DecoratorId])

Sets the list of decorators to be executed after this node.

fn remove_decorators(&mut self)

Removes all decorators from this node.

fn to_display<'a>( &'a self, mast_forest: &'a MastForest, ) -> Box<dyn Display + 'a>

Returns a display formatter for this node.

fn to_pretty_print<'a>( &'a self, mast_forest: &'a MastForest, ) -> Box<dyn PrettyPrint + 'a>

Returns a pretty printer for this node.

fn remap_children(&self, remapping: &BTreeMap<MastNodeId, MastNodeId>) -> Self

Remap the node children to their new positions indicated by the given Remapping.

fn has_children(&self) -> bool

Returns true if the this node has children.

fn append_children_to(&self, target: &mut Vec<MastNodeId>)

Appends the NodeIds of the children of this node, if any, to the vector.

fn for_each_child<F>(&self, f: F)
where F: FnMut(MastNodeId),

Executes the given closure for each child of this node.

fn domain(&self) -> BaseElement

Returns the domain of this node.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors