Module account

Module account 

Domain construction for decoded account messages.

Re-exports

pub use core::Account;
pub use core::AccountCode;
pub use core::AccountCodeUpgrade;
pub use core::AccountHeader;
pub use core::AccountHeaderError;
pub use core::AccountId;
pub use core::AccountIdV1;
pub use core::AccountVersionError;
pub use core::AccountWitness;
pub use storage::AccountStorage;
pub use storage::AccountStorageHeader;
pub use storage::AccountStorageHeaderStorageSlot;
pub use storage::StorageMap;
pub use storage::StorageMapEntry;
pub use storage::StorageMapEntryError;
pub use storage::StorageSlot;
pub use storage::StorageSlotId;
pub use patch::AccountCodePatch;
pub use patch::AccountPatch;
pub use patch::AccountPatchError;
pub use patch::AccountStoragePatch;
pub use patch::AccountUpdateDetails;
pub use patch::AccountVaultPatch;
pub use patch::AccountVaultPatchEntry;
pub use patch::PrivateAccountUpdate;
pub use patch::StorageMapPatch;
pub use patch::StorageMapPatchEntries;
pub use patch::StorageMapPatchError;
pub use patch::StorageSlotPatch;
pub use patch::StorageValuePatch;
pub use patch::VaultPatchError;
pub use partial::PartialAccount;
pub use partial::PartialStorage;
pub use partial::PartialStorageError;
pub use partial::PartialStorageMap;
pub use partial::PartialVault;

Enums

AccountHeaderError
AccountPatchError
AccountVersionError
The message format version of an Account or PartialAccount, distinct from the domain’s AccountIdVersion.
PartialStorageError
StorageMapEntryError
An invariant of a single map entry, distinct from the domain’s StorageMapError.
StorageMapPatchError
VaultPatchError