pub struct StorageMapPatch {
pub operation: Option<Operation>,
}Fields
operation: Option<Operation>Trait Implementations
Sourceimpl Clone for StorageMapPatch
impl Clone for StorageMapPatch
Sourcefn clone(&self) -> StorageMapPatch
fn clone(&self) -> StorageMapPatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageMapPatch
impl Debug for StorageMapPatch
Sourceimpl DecodeMessage for StorageMapPatch
impl DecodeMessage for StorageMapPatch
type Decoded = DecodedStorageMapPatch
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for StorageMapPatch
impl Default for StorageMapPatch
Sourceimpl From<&StorageMapPatch> for StorageMapPatch
impl From<&StorageMapPatch> for StorageMapPatch
Sourcefn from(patch: &StorageMapPatch) -> Self
fn from(patch: &StorageMapPatch) -> Self
Converts to this type from the input type.
Sourceimpl Message for StorageMapPatch
impl Message for StorageMapPatch
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StorageMapPatch
impl PartialEq for StorageMapPatch
impl StructuralPartialEq for StorageMapPatch
Sourceimpl TryFrom<StorageMapPatch> for DecodedStorageMapPatch
impl TryFrom<StorageMapPatch> for DecodedStorageMapPatch
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.