pub struct DecodedBlockHeader {Show 13 fields
pub version: BlockVersion,
pub timestamp: u32,
pub block_num: <BlockNumber as DecodeMessage>::Decoded,
pub prev_block_commitment: <Word as DecodeMessage>::Decoded,
pub chain_commitment: <Word as DecodeMessage>::Decoded,
pub account_root: <Word as DecodeMessage>::Decoded,
pub nullifier_root: <Word as DecodeMessage>::Decoded,
pub note_root: <Word as DecodeMessage>::Decoded,
pub tx_commitment: <Word as DecodeMessage>::Decoded,
pub validator_config: <ValidatorConfig as DecodeMessage>::Decoded,
pub fee_parameters: <FeeParameters as DecodeMessage>::Decoded,
pub protocol_config_commitment: <Word as DecodeMessage>::Decoded,
pub next_protocol_config: OptionalField<<NextProtocolConfig as DecodeMessage>::Decoded>,
}Expand description
Decoded fields of BlockHeader. Domain invariants have not been verified.
Fields
version: BlockVersiontimestamp: u32block_num: <BlockNumber as DecodeMessage>::Decodedprev_block_commitment: <Word as DecodeMessage>::Decodedchain_commitment: <Word as DecodeMessage>::Decodedaccount_root: <Word as DecodeMessage>::Decodednullifier_root: <Word as DecodeMessage>::Decodednote_root: <Word as DecodeMessage>::Decodedtx_commitment: <Word as DecodeMessage>::Decodedvalidator_config: <ValidatorConfig as DecodeMessage>::Decodedfee_parameters: <FeeParameters as DecodeMessage>::Decodedprotocol_config_commitment: <Word as DecodeMessage>::Decodednext_protocol_config: OptionalField<<NextProtocolConfig as DecodeMessage>::Decoded>Trait Implementations
Sourceimpl BuildUnchecked for BlockHeader
Builds a header without validating its parent linkage, signatures, or protocol transition.
impl BuildUnchecked for BlockHeader
Builds a header without validating its parent linkage, signatures, or protocol transition.
type Output = BlockHeader
type Error = VerificationError
fn build_unchecked(self) -> Result<Self::Output, Self::Error>
Sourceimpl Debug for DecodedBlockHeader
impl Debug for DecodedBlockHeader
Sourceimpl TryFrom<BlockHeader> for DecodedBlockHeader
impl TryFrom<BlockHeader> for DecodedBlockHeader
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.