pub struct ValidatorConfig {
pub keys: Vec<PublicKey>,
pub quorum: u32,
}Fields
keys: Vec<PublicKey>quorum: u32Trait Implementations
Sourceimpl Clone for ValidatorConfig
impl Clone for ValidatorConfig
Sourceimpl Debug for ValidatorConfig
impl Debug for ValidatorConfig
Sourceimpl DecodeMessage for ValidatorConfig
impl DecodeMessage for ValidatorConfig
type Decoded = DecodedValidatorConfig
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for ValidatorConfig
impl Default for ValidatorConfig
Sourceimpl From<&ValidatorConfig> for ValidatorConfig
impl From<&ValidatorConfig> for ValidatorConfig
Sourcefn from(value: &ValidatorConfig) -> Self
fn from(value: &ValidatorConfig) -> Self
Converts to this type from the input type.
Sourceimpl From<ValidatorConfig> for ValidatorConfig
impl From<ValidatorConfig> for ValidatorConfig
Sourcefn from(value: ValidatorConfig) -> Self
fn from(value: ValidatorConfig) -> Self
Converts to this type from the input type.
Sourceimpl Message for ValidatorConfig
impl Message for ValidatorConfig
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidatorConfig
impl PartialEq for ValidatorConfig
impl StructuralPartialEq for ValidatorConfig
Sourceimpl TryFrom<ValidatorConfig> for DecodedValidatorConfig
impl TryFrom<ValidatorConfig> for DecodedValidatorConfig
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.