pub struct NoteAttachment {
pub scheme: u32,
pub words: Vec<Word>,
}Fields
scheme: u32words: Vec<Word>Trait Implementations
Sourceimpl Clone for NoteAttachment
impl Clone for NoteAttachment
Sourcefn clone(&self) -> NoteAttachment
fn clone(&self) -> NoteAttachment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NoteAttachment
impl Debug for NoteAttachment
Sourceimpl DecodeMessage for NoteAttachment
impl DecodeMessage for NoteAttachment
type Decoded = DecodedNoteAttachment
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for NoteAttachment
impl Default for NoteAttachment
Sourceimpl From<&NoteAttachment> for NoteAttachment
impl From<&NoteAttachment> for NoteAttachment
Sourcefn from(attachment: &NoteAttachment) -> Self
fn from(attachment: &NoteAttachment) -> Self
Converts to this type from the input type.
Sourceimpl Message for NoteAttachment
impl Message for NoteAttachment
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NoteAttachment
impl PartialEq for NoteAttachment
impl StructuralPartialEq for NoteAttachment
Sourceimpl TryFrom<NoteAttachment> for DecodedNoteAttachment
impl TryFrom<NoteAttachment> for DecodedNoteAttachment
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.