pub struct NoteAttachments {
pub attachments: Vec<NoteAttachment>,
}Fields
attachments: Vec<NoteAttachment>Trait Implementations
Sourceimpl Clone for NoteAttachments
impl Clone for NoteAttachments
Sourceimpl Debug for NoteAttachments
impl Debug for NoteAttachments
Sourceimpl DecodeMessage for NoteAttachments
impl DecodeMessage for NoteAttachments
type Decoded = DecodedNoteAttachments
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for NoteAttachments
impl Default for NoteAttachments
Sourceimpl From<&NoteAttachments> for NoteAttachments
impl From<&NoteAttachments> for NoteAttachments
Sourcefn from(attachments: &NoteAttachments) -> Self
fn from(attachments: &NoteAttachments) -> Self
Converts to this type from the input type.
Sourceimpl From<NoteAttachments> for NoteAttachments
impl From<NoteAttachments> for NoteAttachments
Sourcefn from(attachments: NoteAttachments) -> Self
fn from(attachments: NoteAttachments) -> Self
Converts to this type from the input type.
Sourceimpl Message for NoteAttachments
impl Message for NoteAttachments
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NoteAttachments
impl PartialEq for NoteAttachments
impl StructuralPartialEq for NoteAttachments
Sourceimpl TryFrom<NoteAttachments> for DecodedNoteAttachments
impl TryFrom<NoteAttachments> for DecodedNoteAttachments
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.