pub struct PartialNoteMetadata {
pub version: i32,
pub sender: Option<AccountId>,
pub note_type: i32,
pub tag: u32,
}Fields
version: i32sender: Option<AccountId>note_type: i32tag: u32Implementations
Sourceimpl PartialNoteMetadata
impl PartialNoteMetadata
Sourcepub fn version(&self) -> NoteVersion
pub fn version(&self) -> NoteVersion
Returns the enum value of version, or the default if the field is set to an invalid enum value.
Sourcepub fn set_version(&mut self, value: NoteVersion)
pub fn set_version(&mut self, value: NoteVersion)
Sets version to the provided enum value.
Sourcepub fn note_type(&self) -> NoteType
pub fn note_type(&self) -> NoteType
Returns the enum value of note_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_note_type(&mut self, value: NoteType)
pub fn set_note_type(&mut self, value: NoteType)
Sets note_type to the provided enum value.