pub struct PartialMmr {
pub forest: u64,
pub peaks: Vec<Word>,
pub tracked_leaves: Vec<TrackedMmrLeaf>,
}Fields
forest: u64peaks: Vec<Word>tracked_leaves: Vec<TrackedMmrLeaf>Trait Implementations
Sourceimpl Clone for PartialMmr
impl Clone for PartialMmr
Sourceimpl Debug for PartialMmr
impl Debug for PartialMmr
Sourceimpl DecodeMessage for PartialMmr
impl DecodeMessage for PartialMmr
type Decoded = DecodedPartialMmr
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for PartialMmr
impl Default for PartialMmr
Sourceimpl From<&PartialMmr> for PartialMmr
impl From<&PartialMmr> for PartialMmr
Sourcefn from(mmr: &PartialMmr) -> Self
fn from(mmr: &PartialMmr) -> Self
Converts to this type from the input type.
Sourceimpl From<PartialMmr> for PartialMmr
impl From<PartialMmr> for PartialMmr
Sourcefn from(mmr: PartialMmr) -> Self
fn from(mmr: PartialMmr) -> Self
Converts to this type from the input type.
Sourceimpl Message for PartialMmr
impl Message for PartialMmr
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PartialMmr
impl PartialEq for PartialMmr
impl StructuralPartialEq for PartialMmr
Sourceimpl TryFrom<PartialMmr> for DecodedPartialMmr
impl TryFrom<PartialMmr> for DecodedPartialMmr
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.