pub struct ProtocolConfig {
pub fee_asset_id: Option<Word>,
pub tx_kernel: Option<KernelConfig>,
pub batch_kernel: Option<KernelConfig>,
pub block_kernel: Option<KernelConfig>,
pub proof_verification: Option<ProofVerificationConfig>,
}Fields
fee_asset_id: Option<Word>tx_kernel: Option<KernelConfig>batch_kernel: Option<KernelConfig>block_kernel: Option<KernelConfig>proof_verification: Option<ProofVerificationConfig>Trait Implementations
Sourceimpl Clone for ProtocolConfig
impl Clone for ProtocolConfig
Sourcefn clone(&self) -> ProtocolConfig
fn clone(&self) -> ProtocolConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolConfig
impl Debug for ProtocolConfig
Sourceimpl DecodeMessage for ProtocolConfig
impl DecodeMessage for ProtocolConfig
type Decoded = DecodedProtocolConfig
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for ProtocolConfig
impl Default for ProtocolConfig
Sourceimpl From<&ProtocolConfig> for ProtocolConfig
impl From<&ProtocolConfig> for ProtocolConfig
Sourcefn from(config: &ProtocolConfig) -> Self
fn from(config: &ProtocolConfig) -> Self
Converts to this type from the input type.
Sourceimpl From<ProtocolConfig> for ProtocolConfig
impl From<ProtocolConfig> for ProtocolConfig
Sourcefn from(config: ProtocolConfig) -> Self
fn from(config: ProtocolConfig) -> Self
Converts to this type from the input type.
Sourceimpl Message for ProtocolConfig
impl Message for ProtocolConfig
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProtocolConfig
impl PartialEq for ProtocolConfig
impl StructuralPartialEq for ProtocolConfig
Sourceimpl TryFrom<ProtocolConfig> for DecodedProtocolConfig
impl TryFrom<ProtocolConfig> for DecodedProtocolConfig
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.