pub enum Note {
Authenticated(AuthenticatedInputNote),
Unauthenticated(Note),
}Variants
Authenticated(AuthenticatedInputNote)
Unauthenticated(Note)
Implementations
Sourceimpl Note
impl Note
Sourcepub fn merge(
field: &mut Option<Note>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Note>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourceimpl Note
impl Note
Sourcepub fn into_authenticated(
self,
) -> Result<<AuthenticatedInputNote as DecodeMessage>::Decoded, ConversionError>
pub fn into_authenticated( self, ) -> Result<<AuthenticatedInputNote as DecodeMessage>::Decoded, ConversionError>
Extracts and structurally decodes the authenticated payload without verifying it. Returns a wrong-variant error before decoding if another variant is present.
Sourcepub fn into_unauthenticated(
self,
) -> Result<<Note as DecodeMessage>::Decoded, ConversionError>
pub fn into_unauthenticated( self, ) -> Result<<Note as DecodeMessage>::Decoded, ConversionError>
Extracts and structurally decodes the unauthenticated payload without verifying it. Returns a wrong-variant error before decoding if another variant is present.