pub struct DecodedProvenBatch {
pub reference_block_commitment: <Word as DecodeMessage>::Decoded,
pub reference_block_num: <BlockNumber as DecodeMessage>::Decoded,
pub account_updates: RepeatedField<<BatchAccountUpdate as DecodeMessage>::Decoded>,
pub input_notes: RepeatedField<<InputNoteCommitment as DecodeMessage>::Decoded>,
pub output_notes: RepeatedField<<OutputNote as DecodeMessage>::Decoded>,
pub expiration_block_num: <BlockNumber as DecodeMessage>::Decoded,
pub transactions: RepeatedField<<TransactionHeader as DecodeMessage>::Decoded>,
pub proof: <ExecutionProof as DecodeMessage>::Decoded,
}Expand description
Decoded fields of ProvenBatch. Domain invariants have not been verified.
Fields
reference_block_commitment: <Word as DecodeMessage>::Decodedreference_block_num: <BlockNumber as DecodeMessage>::Decodedaccount_updates: RepeatedField<<BatchAccountUpdate as DecodeMessage>::Decoded>input_notes: RepeatedField<<InputNoteCommitment as DecodeMessage>::Decoded>output_notes: RepeatedField<<OutputNote as DecodeMessage>::Decoded>expiration_block_num: <BlockNumber as DecodeMessage>::Decodedtransactions: RepeatedField<<TransactionHeader as DecodeMessage>::Decoded>proof: <ExecutionProof as DecodeMessage>::DecodedTrait Implementations
Sourceimpl BuildUnchecked for ProvenBatch
Checks local batch invariants, but not proof validity, note aggregation, or transaction
ordering.
impl BuildUnchecked for ProvenBatch
Checks local batch invariants, but not proof validity, note aggregation, or transaction ordering.
type Output = ProvenBatch
type Error = VerificationError
fn build_unchecked(self) -> Result<Self::Output, Self::Error>
Sourceimpl Debug for DecodedProvenBatch
impl Debug for DecodedProvenBatch
Sourceimpl TryFrom<ProvenBatch> for DecodedProvenBatch
impl TryFrom<ProvenBatch> for DecodedProvenBatch
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourceimpl VerifyWith<&ProposedBatch> for ProvenBatch
Checks all fields duplicated from an already-verified proposal. The batch execution proof
still needs verification by the consuming service; this only establishes proposal agreement.
impl VerifyWith<&ProposedBatch> for ProvenBatch
Checks all fields duplicated from an already-verified proposal. The batch execution proof still needs verification by the consuming service; this only establishes proposal agreement.
type Verified = ProvenBatch
type Error = VerificationError
fn verify_with( self, proposed: &ProposedBatch, ) -> Result<Self::Verified, Self::Error>