pub struct TransactionArgs {
pub tx_script: Option<TransactionScript>,
pub tx_script_args: Option<Word>,
pub note_args: Vec<NoteArgument>,
pub advice_inputs: Option<AdviceInputs>,
pub auth_args: Option<Word>,
}Fields
tx_script: Option<TransactionScript>tx_script_args: Option<Word>note_args: Vec<NoteArgument>advice_inputs: Option<AdviceInputs>auth_args: Option<Word>Trait Implementations
Sourceimpl Clone for TransactionArgs
impl Clone for TransactionArgs
Sourcefn clone(&self) -> TransactionArgs
fn clone(&self) -> TransactionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionArgs
impl Debug for TransactionArgs
Sourceimpl Default for TransactionArgs
impl Default for TransactionArgs
Sourceimpl From<&TransactionArgs> for TransactionArgs
impl From<&TransactionArgs> for TransactionArgs
Sourcefn from(value: &TransactionArgs) -> Self
fn from(value: &TransactionArgs) -> Self
Converts to this type from the input type.
Sourceimpl From<TransactionArgs> for TransactionArgs
impl From<TransactionArgs> for TransactionArgs
Sourcefn from(value: TransactionArgs) -> Self
fn from(value: TransactionArgs) -> Self
Converts to this type from the input type.
Sourceimpl Message for TransactionArgs
impl Message for TransactionArgs
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TransactionArgs
impl PartialEq for TransactionArgs
impl StructuralPartialEq for TransactionArgs
Sourceimpl TryFrom<TransactionArgs> for TransactionArgs
impl TryFrom<TransactionArgs> for TransactionArgs
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.