Domain construction for decoded primitives messages.
Re-exports
pub use merkle::MerklePath;pub use merkle::MmrDelta;pub use merkle::SparseMerklePath;pub use smt::IndexedDigest;pub use smt::IndexedSmtLeaf;pub use smt::PartialSmt;pub use smt::PartialSmtNode;pub use smt::PartialSmtNodeLevel;pub use smt::SmtLeaf;pub use smt::SmtLeafEntry;pub use smt::SmtLeafEntryList;pub use smt::SmtOpening;pub use advice::AdviceInputs;pub use advice::AdviceMap;pub use advice::AdviceMapEntry;pub use advice::AdviceStack;pub use advice::MerkleStore;pub use advice::MerkleStoreNode;pub use mast::MastForest;pub use crypto::PublicKey;pub use crypto::Signature;
Structs
- Canonical
- A canonically deserialized byte payload, with no verification of its application use.
- Untrusted
Mast Forest - A parsed MAST payload whose structure and node hashes have not yet been verified.